@@ -14,7 +14,8 @@
 #include "screen.h"
 #include "progress.h"
 
-#define MAX_THREADS 50
+#define MAX_THREADS 50				/* maximum number of threads */
+#define NUM_THREADS_FACTOR 0.7		/* defalt number of threads = real number of thread * THREADS_FACTOR */
 #define LLUI long long unsigned int
 #define MAX_FILTER_LEN 1024
 
@@ -150,7 +151,7 @@ int main(int argc, char **argv) {
 
 	flist_init(&flist);
 
-	numthreads = get_cpu_cores();
+	numthreads = get_cpu_cores() * NUM_THREADS_FACTOR;
 
 	/* initalise one instance of memory heap (share by all threads) */
 	memp = NULL;
@@ -177,6 +178,10 @@ int main(int argc, char **argv) {
 				break;
 			case 'O':
 				sortfield = lnf_fld_parse(optarg, &sortbits4, &sortbits6);
+				if (sortfield == 0) {
+					fprintf(stderr, "Unknow or unsupported sort field: %s\n", optarg);
+					exit(1);
+				}
 				break;
 			case 'T': 
 				numthreads = atoi(optarg);
@@ -246,6 +251,7 @@ int main(int argc, char **argv) {
 		lnf_mem_fadd(memp, sortfield, defaultaggr|defaultsort, sortbits4, sortbits6);
 	}
 
+
 	print_header();
 
 	/*  prepare and run threads */
